@@ -927,7 +927,18 @@ class opensshStatus(StatusMenuItem):
                     self.button.set_text("OpenSSH Server ", "On")
                 self.button.set_image(self.image_on)
                 self.set_status_area_icon(self.icon)
+                self.on = True
                 system("sudo openssh-status.sh disconnect")
+        else:
+            system("sudo openssh-status.sh start_sshd")
+            if self.trackingEnabled:
+                self.labelConnected = 0
+                self.button.set_text("OpenSSH Server ", "0 connections")
+            else:
+                self.button.set_text("OpenSSH Server ", "On")
+            self.button.set_image(self.image_on)
+            self.set_status_area_icon(self.icon)
+            self.on = True
             
     def printDialog(self, msg):
         system("run-standalone.sh dbus-send \
